## Python обертка для запросов в БД [Clickhouse](https://clickhouse.yandex/)

Написано на версии python 3.5

## Установка
```
pip install clickhousepy
или
pip install clickhousepy[pandas](для установки pandas)
```

## Зависимости
- [clickhouse-driver](https://github.com/mymarilyn/clickhouse-driver/)
- [pandas](https://github.com/pandas-dev/pandas) (Опционально)
